Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(412)

Unified Diff: third_party/WebKit/Source/core/html/HTMLObjectElement.cpp

Issue 2737713002: Rename updateWidgets to updatePlugins (Closed)
Patch Set: Rename updateWidgets to updatePlugins Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/html/HTMLObjectElement.cpp
diff --git a/third_party/WebKit/Source/core/html/HTMLObjectElement.cpp b/third_party/WebKit/Source/core/html/HTMLObjectElement.cpp
index a545e4b046e165b95774e3e01371942251cea104..6353215395e0e2b61bb45f25df5da17e72031d9c 100644
--- a/third_party/WebKit/Source/core/html/HTMLObjectElement.cpp
+++ b/third_party/WebKit/Source/core/html/HTMLObjectElement.cpp
@@ -112,7 +112,7 @@ void HTMLObjectElement::parseAttribute(
} else if (name == dataAttr) {
m_url = stripLeadingAndTrailingHTMLSpaces(params.newValue);
if (layoutObject() && isImageType()) {
- setNeedsWidgetUpdate(true);
+ setNeedsPluginUpdate(true);
if (!m_imageLoader)
m_imageLoader = HTMLImageLoader::create(this);
m_imageLoader->updateFromElement(ImageLoader::UpdateIgnorePreviousError);
@@ -264,17 +264,17 @@ void HTMLObjectElement::reloadPluginOnAttributeChange(
NOTREACHED();
needsInvalidation = false;
}
- setNeedsWidgetUpdate(true);
+ setNeedsPluginUpdate(true);
if (needsInvalidation)
lazyReattachIfNeeded();
}
// TODO(schenney): crbug.com/572908 This should be unified with
-// HTMLEmbedElement::updateWidget and moved down into HTMLPluginElement.cpp
-void HTMLObjectElement::updateWidgetInternal() {
+// HTMLEmbedElement::updatePlugin and moved down into HTMLPluginElement.cpp
+void HTMLObjectElement::updatePluginInternal() {
DCHECK(!layoutEmbeddedItem().showsUnavailablePluginIndicator());
- DCHECK(needsWidgetUpdate());
- setNeedsWidgetUpdate(false);
+ DCHECK(needsPluginUpdate());
+ setNeedsPluginUpdate(false);
// TODO(schenney): crbug.com/572908 This should ASSERT
// isFinishedParsingChildren() instead.
if (!isFinishedParsingChildren()) {
@@ -342,7 +342,7 @@ void HTMLObjectElement::removedFrom(ContainerNode* insertionPoint) {
void HTMLObjectElement::childrenChanged(const ChildrenChange& change) {
if (isConnected() && !useFallbackContent()) {
- setNeedsWidgetUpdate(true);
+ setNeedsPluginUpdate(true);
lazyReattachIfNeeded();
}
HTMLPlugInElement::childrenChanged(change);
« no previous file with comments | « third_party/WebKit/Source/core/html/HTMLObjectElement.h ('k') | third_party/WebKit/Source/core/html/HTMLPlugInElement.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698